@@ -78,9 +78,9 @@ install_tinytex = function(
     system2(bin, c('conf', 'auxtrees', 'add', r_texmf_path()))
   }
   https = grepl('^https://', repository)
-  if (not_ctan <- repository != 'ctan') {
-    repository = sub('systems/texlive/tlnet/?$', '', repository)
-    repository = paste0(sub('/+$', '', repository), '/', 'systems/texlive/tlnet')
+  repository = sub('/+$', '', repository)
+  if ((not_ctan <- repository != 'ctan') && !grepl('/tlnet$', repository)) {
+    repository = paste0(repository, '/systems/texlive/tlnet')
   }
 
   if ((texinput <- Sys.getenv('TEXINPUT')) != '') message(
